summaryrefslogtreecommitdiff
path: root/src/lib/format.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-01-23 20:06:37 +0000
committerCarl Hetherington <cth@carlh.net>2013-01-23 20:06:37 +0000
commitd1b20374b1bd02b2929c9c3080c006874b525ef5 (patch)
treec35e9150caf5c6cdea75d4b223cb5bbd0b28032a /src/lib/format.h
parent125e52fbb84ab9a28f3cc9cf8a74dc8a568d4049 (diff)
Remove multi-reel, for now, and sort out Size vs libdcp::Size.
Diffstat (limited to 'src/lib/format.h')
-rw-r--r--src/lib/format.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/lib/format.h b/src/lib/format.h
index 2118237a4..b4c691e56 100644
--- a/src/lib/format.h
+++ b/src/lib/format.h
@@ -31,7 +31,7 @@ class Film;
class Format
{
public:
- Format (Size dcp, std::string id, std::string n, std::string d)
+ Format (libdcp::Size dcp, std::string id, std::string n, std::string d)
: _dcp_size (dcp)
, _id (id)
, _nickname (n)
@@ -52,7 +52,7 @@ public:
* put in a DCP for this ratio. This size will not correspond
* to the ratio when we are doing things like 16:9 in a Flat frame.
*/
- Size dcp_size () const {
+ libdcp::Size dcp_size () const {
return _dcp_size;
}
@@ -81,11 +81,11 @@ public:
static void setup_formats ();
protected:
/** Size in pixels of the images that we should
* put in a DCP for this ratio. This size will not correspond
* to the ratio when we are doing things like 16:9 in a Flat frame.
*/
- Size _dcp_size;
+ libdcp::Size _dcp_size;
/** id for use in metadata */
std::string _id;
/** nickname (e.g. Flat, Scope) */
@@ -104,7 +104,7 @@ private:
class FixedFormat : public Format
{
public:
- FixedFormat (int, Size, std::string, std::string, std::string);
+ FixedFormat (int, libdcp::Size, std::string, std::string, std::string);
int ratio_as_integer (boost::shared_ptr<const Film>) const {
return _ratio;
@@ -125,7 +125,7 @@ private:
class VariableFormat : public Format
{
public:
- VariableFormat (Size, std::string, std::string, std::string);
+ VariableFormat (libdcp::Size, std::string, std::string, std::string);
int ratio_as_integer (boost::shared_ptr<const Film> f) const;
float ratio_as_float (boost::shared_ptr<const Film> f) const;
@@ -81,11 +81,11 @@ public:
static void setup_formats ();
protected:
- /** Size in pixels of the images that we should
+ /** libdcp::Size in pixels of the images that we should
* put in a DCP for this ratio. This size will not correspond
* to the ratio when we are doing things like 16:9 in a Flat frame.